<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jan 27, 2020
 */

require_once(__DIR__ . '/../Model/Auth/User.php');
require_once(__DIR__ . '/../Model/BackupAgent/BackupAgent.php');

/**
 * Class for installing acronis backup cloud.
 *
 * @package InterWorx
 * @subpackage CLI
 */
class AcronisInstaller extends CLI
{
    const URL = 'url';
    const PASSWORD = 'password';
    const USERNAME = 'username';

    private $_BackupAgent;

    /**
     * Register functions, install & uninstall.
     */
    public function registerOptArgs()
    {
        $this->_func('install', 'install backup agent');
        $this->_func('uninstall', 'uninstall backup agent');
    }

    /**
     * Uninstall acronis backup agent.
     */
    protected function _uninstall()
    {
        $BackupAgent = $this->_getBackupAgent();

        if (!$BackupAgent->isInstalled()) {
            $this->fail('Acronis is not installed, nothing to do.');
        }

        try {
            $BackupAgent->uninstall();
            $this->success('Backup agent removed!');
        } catch (Exception $e) {
            $this->fail($e->getMessage());
        }
    }

    /**
     * Install Backup Agent.
     * No distro check as we don't support anything that acronis don't.
     */
    protected function _install()
    {
        $BackupAgent = $this->_getBackupAgent();

        if ($BackupAgent->isInstalled()) {
            $this->fail('Acronis is already installed, nothing to do.');
        }

        try {
            $BackupAgent->install();
            $this->success('Backup agent installed!');
        } catch (Exception $e) {
            $this->fail($e->getMessage());
        }
    }


    /**
     * Get backup agent.
     */
    private function _getBackupAgent()
    {
        if (!isset($this->_BackupAgent)) {
            $this->_BackupAgent = new Model_BackupAgent_BackupAgent();
        }

        return $this->_BackupAgent;
    }
}
