<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jun 04, 2020
 */

/**
 * Cron class - registered as daily task.
 *
 * @package Interworx
 * @subpackage Cron
 */
class Cron_Acronis extends Cron_Abstract
{
    const NW_PATH_BACKUPS_ALTLOCATION = Model_RecoveryPoint_Files::NW_DOWNLOAD_DIR_PATH;

    /**
     * Execute, will run daily and delete any
     * backup to alt location older than 7 days.
     */
    protected function _execute()
    {
        $this->_deleteOldBackupsIfPathExists(self::NW_PATH_BACKUPS_ALTLOCATION);

        $Accounts = SiteWorx::getValidAccounts();
        foreach ($Accounts as $SW) {
            $path = Model_RecoveryPoint_Files_Siteworx::getRestoreAltLocationPath($SW);
            $this->_deleteOldBackupsIfPathExists($path);
        }
    }

    /**
     * Delete old backups if path exists.
     *
     * @param string $path
     */
    private function _deleteOldBackupsIfPathExists($path)
    {
        if (is_dir($path)) {
            $this->_deleteExpiredFiles($path);
        }
    }

    /**
     * Delete expired backups.
     * Backups are considered expired 7 days after creation.
     *
     * @param string $path
     */
    private function _deleteExpiredFiles($path)
    {
        $deleteOldFiles = "if [ -d \"$path\" ]; then find $path/ -maxdepth 1 -mtime +7 -exec rm -rf {} +; fi";

        $Command = new Command($deleteOldFiles);
        $Command->allowQuoteDouble();
        $Command->allowBracketBoth();
        $Command->allowSemicolon();
        $Command->runAsRoot();
        $Command->exec();
    }
}
