<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 04, 2020
 */

/**
 *
 * @package InterWorx
 * @subpackage Plugin_Acronis
 */
class Model_Alerts_AlertManager extends Model_Acronis
{

    /**
     * Get alerts.
     */
    public function getAlerts()
    {
        $resourceName = gethostname();
        $resourceAlerts = $this->_getAlertsForResource($resourceName);
        $this->_logAlerts($resourceAlerts);

        $result = $this->_formatAlerts($resourceAlerts);
        return $result;
    }

    /**
     *
     *
     * @param string $resourceName
     */
    private function _getAlertsForResource($resourceName)
    {
        $alerts = $this->_getApi()->getAlerts();
        $result = array();

        foreach ($alerts as $alert) {
            $details = $alert['details'];
            $alertResourceName = $details['resourceName'];
            if ($alertResourceName === $resourceName) {
                $result[] = $alert;
            }
        }

        return $result;
    }

    /**
     * Log alerts.
     *
     * @param array $alerts
     */
    private function _logAlerts(array $alerts)
    {
        foreach ($alerts as $alert) {
            $severity = $alert['severity'];
            $type = $alert['type'];
            $details = $alert['details'];
            $error = $details['errorMessage'];
            $context = $error['context'];
            $cause = $context['cause_str'];
            IW::getLog()->error("ACRONIS ALERT - Severity: $severity. Type: $type. Cause: $cause. Log into the acronis cloud platform for more information.");
        }
    }

    /**
     *
     * @param array $alerts
     */
    private function _formatAlerts(array $alerts)
    {
        $result = array_map(function ($alert) {

            $severity = $alert['severity'];
            $type = $alert['type'];
            $createdAt = $alert['createdAt'];

            return array(
                'type' => $type,
                'createdAt' => $createdAt,
                'severity' => $severity
            );
        }, $alerts);

        return $result;
    }
}
