<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 13, 2020
 */

/**
 * Acronis User class.
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Auth_User
{
    private $_datacenterUrl;
    private $_username;
    private $_password;
    private $_tenantId;
    private $_userId;


    /**
     * constructor.
     *
     * @param string $username
     * @param string $password
     * @param string $datacenterUrl
     */
    public function __construct($username, $password, $datacenterUrl)
    {
        $credentials = array($username, $password, $datacenterUrl);
        $this->_verifyFormat($credentials);

        $this->_username = $username;
        $this->_password = $password;
        $this->_datacenterUrl = $datacenterUrl;
    }

    /**
     * Verify that credentials are in right format.
     *
     * @param array $credentials
     */
    private function _verifyFormat(array $credentials)
    {
        foreach ($credentials as $credential) {
            $this->_throwExceptionWrongFormat($credential);
        }
    }

    /**
     * Check credentials format.
     *
     * @param string $credential
     * @throws Exception
     */
    private function _throwExceptionWrongFormat($credential)
    {
        if (!is_string($credential) || $credential === '') {
            throw new Exception('User credentials not valid!');
        }
    }

    /**
     * Get basic credentials.
     *
     * @return string
     */
    public function getBasicCredentials()
    {
        return base64_encode("$this->_username:$this->_password");
    }

    /**
     * Set tenantId.
     *
     * @param string $tenantId
     */
    public function setTenantId($tenantId)
    {
        $this->_tenantId = $tenantId;
    }

    /**
     * Get tenantId.
     *
     * @return string
     */
    public function getTenantId()
    {
        return $this->_tenantId;
    }


    /**
     * Set userId.
     *
     * @param string $userId
     */
    public function setUserId($userId)
    {
        $this->_userId = $userId;
    }

    /**
     * Get userId.
     *
     * @return string
     */
    public function getUserId()
    {
        return $this->_userId;
    }

    /**
     * Get datacenterUrl.
     *
     * @return string
     */
    public function getDatacenterUrl()
    {
        return $this->_datacenterUrl;
    }

    /**
     * Get username
     *
     * @return string
     */
    public function getUsername()
    {
        return $this->_username;
    }

    /**
     *
     */
    public function getPassword()
    {
        return $this->_password;
    }
}
