<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 12, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_Backups extends Model_Acronis
{
    private $_instanceId;

    /**
     * @param string $instanceId
     */
    public function __construct($instanceId)
    {
        $this->_instanceId = $instanceId;
    }

    /**
     * Get backups.
     *
     * @return array
     */
    public function getBackups()
    {
        $this->_getCache()->deleteAll();
        $backups = $this->_getBackupsFromApi();
        $this->_getCache()->cacheBackups($backups);
        return $backups;
    }

    /**
     * Get backups from api.
     *
     * @return array
     */
    private function _getBackupsFromApi()
    {
        $backups = $this->_getApi()->getBackups($this->_instanceId);
        $result = array();

        foreach ($backups as $backup) {
            $date = $this->_formatDate($backup['created']);

            $backupId = $backup['backup_id'];
            $legacyId = $backup['legacy_id'];
            $archive = $backup['archive'];

            $vaultId = $archive['vault_id'];
            $archiveId = $archive['id'];
            $machineId = $archive['agent_id'];

            $result[] = array(
                'date' => $date,
                'backupId' => $backupId,
                'legacyId' => $legacyId,
                'vaultId' => $vaultId,
                'archiveId' => $archiveId,
                'machineId' => $machineId,
                'created' => $backup['created'],
                'tenantAgentId' => $backup['tenant_id']
            );
        }

        return $result;
    }
}
