<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 22, 2020
 */

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Backups_PlanDraft extends Model_Acronis
{
    private $_draftId;
    private $_planId;

    /**
     * Creates draft in api.
     *
     * @param string $resourceId
     */
    public function __construct($resourceId)
    {
        $this->_createDraft($resourceId);
    }

    /**
     * Create draft.
     *
     * @param string $resourceId
     */
    private function _createDraft($resourceId)
    {
        $Api = $this->_getApi();

        $draftId = $Api->createDraft($resourceId)['DraftID'];
        $Api->updateDraftDailyBackups($draftId);

        $this->_draftId = $draftId;
    }

    public function getPlanDraft()
    {
        return $this->_getApi()->getPlanDraft($this->_draftId);
    }

    /**
     * Create plan.
     */
    public function createPlan()
    {
        $apiRes = $this->_getApi()->createPlan($this->_draftId);
        $this->_planId = $apiRes['PlanID'];
        $this->_getCache()->cachePlanId($this->_planId);
    }

    /**
     * Get plan id once plan has been created.
     */
    public function getPlanId()
    {
        if (!isset($this->_planId)) {
            throw new Exception('No plan has been created!');
        }

        return $this->_planId;
    }
}
