<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 23, 2020
 */

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Cache
{
    const CACHE_INSTANCE_ID = 'instanceid.acronis';
    const CACHE_RESOURCE_ID = 'resourceid.acronis';
    const CACHE_PLAN_ID = 'planid.acronis';
    const CACHE_DEVICEINFO = 'deviceinfo.acronis';
    const CACHE_PLAN = 'plan.acronis';
    const CACHE_BACKUPS = 'backups.acronis';
    const CACHE_DIRECTORIES = 'directories.acronis';
    const CACHE_AGENT_TENANT_ID = 'agenttenantid.acronis';
    const CACHE_DB_DUMPS = 'dbdumps.acronis';
    const CACHE_DIR_BY_PATH = 'backups.path.acronis';

    const TWENTY_DAYS = '1728000';

    /**
     * Cache instance id.
     *
     * @param string $instanceId
     */
    public function cacheInstanceId($instanceId)
    {
        $this->_setCache(self::CACHE_INSTANCE_ID, $instanceId);
    }

    /**
     * Get instance id.
     *
     * @return string
     */
    public function getInstanceId()
    {
        return $this->_getCache(self::CACHE_INSTANCE_ID);
    }

    /**
     * Cache resource id.
     *
     * @param string $resourceId
     */
    public function cacheResourceId($resourceId)
    {
        $this->_setCache(self::CACHE_RESOURCE_ID, $resourceId);
    }


    /**
     * Get resource id.
     *
     * @return string
     */
    public function getResourceId()
    {
        return $this->_getCache(self::CACHE_RESOURCE_ID);
    }

    /**
     * Cache device info.
     *
     * @param array $deviceInfo
     */
    public function cacheDeviceInfo(array $deviceInfo)
    {
        $this->_setTempCache(self::CACHE_DEVICEINFO, $deviceInfo);
    }

    /**
     * Get device info.
     *
     * @return array
     */
    public function getDeviceInfo()
    {
        return $this->_getCachedArray(self::CACHE_DEVICEINFO);
    }

    /**
     * Cache plan.
     *
     * @param array $plan
     */
    public function cachePlan(array $plan)
    {
        $this->_setTempCache(self::CACHE_PLAN, $plan);
    }

    /**
     * Get plan.
     *
     * @return array
     */
    public function getPlan()
    {
        return $this->_getCachedArray(self::CACHE_PLAN);
    }

    /**
     * Cache plan id.
     *
     * @param string $id
     */
    public function cachePlanId($id)
    {
        $this->_setCache(self::CACHE_PLAN_ID, $id);
    }

    /**
     * get plan id.
     *
     * @return string
     */
    public function getPlanId()
    {
        return $this->_getCache(self::CACHE_PLAN_ID);
    }

    /**
     * delete plan id.
     */
    public function deletePlanId()
    {
        $this->_deleteCache(self::CACHE_PLAN_ID);
    }

    /**
     * Get backups.
     *
     * @return array
     */
    public function getBackups()
    {
        return $this->_getCachedArray(self::CACHE_BACKUPS);
    }

    /**
     * Cache backups.
     *
     * @param array $backups
     */
    public function cacheBackups(array $backups)
    {
        $this->_setCache(self::CACHE_BACKUPS, $backups);
    }

    /**
     * Get agent tenant id.
     *
     * @return string
     */
    public function getAgentTenantId()
    {
        return $this->_getCache(self::CACHE_AGENT_TENANT_ID);
    }

    /**
     * cache agent tenant id.
     *
     * @param string $id
     */
    public function cacheAgentTenantId($id)
    {
        $this->_setCache(self::CACHE_AGENT_TENANT_ID, $id);
    }



    /**
     * Get backup by id.
     *
     * @param string $id
     * @return array
     */
    public function getBackupById($id)
    {
        $backups = $this->getBackups();
        if (empty($backups)) {
            throw new Exception('Could not get backup by id, no backups have been cached!');
        }

        foreach ($backups as $backup) {
            if ($backup['backupId'] === $id) {
                return $backup;
            }
        }
    }

    /**
     *
     * @param string $backupId
     */
    public function getDumpsInfo($backupId)
    {
        $dumps = $this->_getDumps();
        return $dumps[$backupId];
    }

    /**
     * Cache dumps.
     *
     * @param string $backupId
     * @param array  $dumpsToCache
     */
    public function cacheDumps($backupId, array $dumpsToCache)
    {
        $dumps = $this->_getDumps();
        if (!isset($dumps)) {
            $dumps = array();
        }

        $dumps[$backupId] = $dumpsToCache;
        $this->_setDumps($dumps);
    }


    /**
     * @return array
     */
    private function _getDumps()
    {
        return $this->_getCachedArray(self::CACHE_DB_DUMPS);
    }

    /**
     * Set db dumps.
     *
     * @param array $dumps
     */
    private function _setDumps(array $dumps)
    {
        $cacheForTwentyDays = '1728000';
        $this->_setCache(self::CACHE_DB_DUMPS, $dumps, $cacheForTwentyDays);
    }

    /**
     * Cache dir.
     *
     * @param string $backupId
     * @param array  $dir
     */
    public function cacheDir($backupId, array $dir)
    {
        $backupDirs = $this->_getBackupDirs($backupId);
        $backupDirs[] = $dir;
        $this->_replaceBackupDirs($backupId, $backupDirs);
    }

    /**
     * Get centos root.
     *
     * @param string $backupId
     * @return array
     */
    public function getCentosRoot($backupId)
    {
        $backupDirs = $this->_getBackupDirs($backupId);

        foreach ($backupDirs as $dir) {
            if ($dir['name'] === Model_RecoveryPoint_Abstract::CENTOS_ROOT) {
                return $dir;
            }
        }
    }
    /**
     * Get directories.
     *
     * @return array
     */
    public function getDirectories()
    {
        return $this->_getCachedArray(self::CACHE_DIRECTORIES);
    }


    /**
     * Get directory & content.
     *
     * @param string $backupId
     * @param string $dirId
     */
    public function getDirById($backupId, $dirId)
    {
        $backupDirs = $this->_getBackupDirs($backupId);

        if (!empty($backupDirs)) {
            $dir = $this->_getDirById($dirId, $backupDirs);
            return $dir;
        }
    }

    /**
     * Get dir by dir id.
     *
     * @param string $dirId
     * @param array  $backupDirs
     * @return array
     */
    private function _getDirById($dirId, array $backupDirs)
    {
        foreach ($backupDirs as $dir) {
            if ($dir['id'] === $dirId) {
                return $dir;
            }
        }
    }


    /**
     *
     *
     * @param string $backupId
     * @param string $dirId
     */
    public function getChildDirById($backupId, $dirId)
    {
        $backupDirs = $this->_getBackupDirs($backupId);

        foreach ($backupDirs as $parent) {
            $dir = $this->_getDirById($dirId, $parent['content']);
            if ($dir !== null) {
                return $dir;
            }
        }
    }

    /**
     * Get file details - does not include content.
     *
     * @param string $backupId
     * @param string $dirId
     */
    public function getFileDetails($backupId, $dirId)
    {
        $backupDirs = $this->_getBackupDirs($backupId);
        foreach ($backupDirs as $dir) {
            foreach ($dir['content'] as $child) {
                if ($child['id'] === $dirId) {
                    return $child;
                }
            }
        }
    }

    /**
     * Get directories.
     *
     * @return array
     */
    private function _getDirectories()
    {
        return $this->_getCachedArray(self::CACHE_DIRECTORIES);
    }

    /**
     * Get backup directories.
     *
     * @param string $backupId
     * @return array
     */
    private function _getBackupDirs($backupId)
    {
        $dirs = $this->_getDirectories();

        if (empty($dirs) || empty($dirs[$backupId])) {
            return array();
        }

        return $dirs[$backupId];
    }

    /**
     * Add backup to directory cache.
     *
     * @param string $backupId
     * @param array  $backupDirs
     */
    private function _replaceBackupDirs($backupId, array $backupDirs)
    {
        $dirs = $this->_getDirectories();
        if (empty($dirs)) {
            $dirs = array();
        }

        $dirs[$backupId] = $backupDirs;
        $this->_cacheDirectories($dirs);
    }

    /**
     * Cache directories.
     *
     * @param array $dirs
     */
    private function _cacheDirectories(array $dirs)
    {
        $this->_setCache(self::CACHE_DIRECTORIES, $dirs, self::TWENTY_DAYS);
    }

    /**
     * @param string $backupId
     * @param string $path
     */
    public function getDirByPath($backupId, $path)
    {
        $backup = $this->_getPathBackupByBackupId($backupId);
        return $backup[$path];
    }

    /**
     * @param string $backupId
     * @param string $path
     * @param array  $dir
     */
    public function cacheDirByPath($backupId, $path, array $dir)
    {
        $backup = $this->_getPathBackupByBackupId($backupId);
        $backup[$path] = $dir;

        $this->_savePathBackupByBackupId($backupId, $backup);
    }

    /**
     * @param string $id
     */
    private function _getPathBackupByBackupId($id)
    {
        $backups = $this->_getCachedArray(self::CACHE_DIR_BY_PATH);
        if (!isset($backups)) {
            $backups = array();
        }

        return $backups[$id] === null ? array() : $backups[$id];
    }

    /**
     * @param string $backupId
     * @param array  $backup
     */
    private function _savePathBackupByBackupId($backupId, array $backup)
    {
        $backups = $this->_getCachedArray(self::CACHE_DIR_BY_PATH);
        $backups = isset($backups) ? $backups : array();
        $backups[$backupId] = $backup;
        $this->_setCache(self::CACHE_DIR_BY_PATH, $backups);
    }

    /**
     * Get cached values.
     *
     * @param string $name
     */
    protected function _getCache($name)
    {
        return IW::Cache()->get($name);
    }


    /**
     * Format cached return object to assoc array.
     *
     * @param string $cacheName
     * @return array
     */
    private function _getCachedArray($cacheName)
    {
        $cachedObject = $this->_getCache($cacheName);

        $assoc = true;
        return json_decode(json_encode($cachedObject), $assoc);
    }

    /**
     * Set permanent cache.
     *
     * @param string  $name
     * @param mixed   $data
     * @param integer $time
     */
    private function _setCache($name, $data, $time = 0)
    {
        IW::Cache()->set($name, $data, $time);
    }

    /**
     * Set temporary cache. Will be cleared after 10 sec.
     *
     * @param string $name
     * @param mixed  $data
     */
    private function _setTempCache($name, $data)
    {
        $seconds = 5;
        IW::Cache()->set($name, $data, $seconds);
    }


    /**
     * Delete cache.
     *
     * @param string $name
     */
    private function _deleteCache($name)
    {
        IW::Cache()->delete($name);
    }

    /**
     * Delete all cached values.
     */
    public function deleteAll()
    {
        $all = $this->_getAllCacheConsts();
        foreach ($all as $cache) {
            $this->_deleteCache($cache);
        }
    }

    /**
     * Get all const in class.
     *
     * @return array
     */
    private function _getAllCacheConsts()
    {
        $thisClass = new ReflectionClass(__CLASS__);
        return $thisClass->getConstants();
    }
}
