<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Sep 14, 2020
 */

use Monolog\Logger;

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
abstract class Model_Logger_Activities
{
    const LOG_DIR = '/home/interworx/var/log/acronis';
    const ACTIVITY_RESTOREFILES = 'File Restoration';
    const ACTIVITY_DOWNLOADFILES = 'File Download';
    const ACTIVITY_RESTOREDBS = 'Database Restoration';
    const ACTIVITY_DOWNLOADDBS = 'Database Download';

    private $_Logger;

    /**
     * @param Logger $Logger
     */
    public function __construct(Logger $Logger)
    {
        $this->_Logger = $Logger;
    }


    /**
     * @param array $files
     */
    public function logRestoreFiles(array $files)
    {
        $this->_logActivity(self::ACTIVITY_RESTOREFILES, $files);
    }

    /**
     * @param array $files
     */
    public function logDownloadFiles(array $files)
    {
        $this->_logActivity(self::ACTIVITY_DOWNLOADFILES, $files);
    }

    /**
     * @param array $dbs
     */
    public function logRestoreDatabases(array $dbs)
    {
        $this->_logActivity(self::ACTIVITY_RESTOREDBS, $dbs);
    }

    /**
     * @param array $dbs
     */
    public function logDownloadDatabases(array $dbs)
    {
        $this->_logActivity(self::ACTIVITY_DOWNLOADDBS, $dbs);
    }


    /**
     * @param string $activity
     * @param array  $items
     */
    private function _logActivity($activity, array $items)
    {
        $this->_Logger->info($activity, ['items' => $items]);
    }
}
