<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 28, 2020
 */

/**
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_RecoveryPoint_Databases_Nodeworx extends Model_RecoveryPoint_Databases
{
    /**
     * Get db details by parsing db dump file names.
     * Will restore dumps if value isn't cached or restored already.
     *
     * @return array
     */
    public function getDbs()
    {
        $Cache = $this->_getCache();
        $dbInfo = $Cache->getDumpsInfo($this->getBackupId());

        if (!isset($dbInfo)) {
            $dbInfo = $this->_getDumpsInfoFromApi();
            $Cache->cacheDumps($this->getBackupId(), $dbInfo);
        }

        return $dbInfo;
    }

    /**
     * Restore db dumps.
     *
     * @param string $unixUser
     * @param array  $dbs
     */
    public function restoreDatabases($unixUser, array $dbs)
    {
        $this->_restoreUserDumps($unixUser);
        $this->_awaitUserDumpsRestoration($unixUser);

        $this->_restoreDatabases($unixUser, $dbs);
    }

    /**
     * restore databases. Expects arrays with values 'unixUser' and 'dbName'.
     *
     * @param string $user
     * @param array  $dbs
     */
    private function _restoreDatabases($user, array $dbs)
    {
        try {
            $this->_restoreSwDatabases($user, $dbs);
        } catch (Exception_AccountDoesNotExist $e) {
            $this->_restoreUnmappedDatabases($dbs);
        }
    }

    /**
     * @param string $user
     * @param array  $databases
     */
    private function _restoreSwDatabases($user, array $databases)
    {
        $SwRecoveryPointDatabases = new Model_RecoveryPoint_Databases_Siteworx($this->getBackupId(), $user);
        $SwRecoveryPointDatabases->restoreDatabases($databases);
    }

    /**
     * Restore unmapped dbs.
     *
     * @param array $dbs
     */
    private function _restoreUnmappedDatabases(array $dbs)
    {
        foreach ($dbs as $dbName) {
            $dumpsPath = $this->_getDumpsPathByUnixUser('system') . "/$dbName";
            $this->_unzipUnmappedDatabaseArchive($dumpsPath, $dbName);

            $sqlFiles = $this->_getSqlFiles($dumpsPath, $dbName);
            $this->_restoreUnmappedDatabase($dbName, $sqlFiles);
        }
    }

    /**
     * unzip archives.
     *
     * @param string $dumpsPath
     * @param string $dbName
     */
    private function _unzipUnmappedDatabaseArchive($dumpsPath, $dbName)
    {
        if ($dbName !== 'mysql') {
            $archives = $this->_getTableArchives($dumpsPath);
            $this->_unzipArchivesUnmappedDb($archives);
        }
    }

    /**
     * Unzip archives in current destination.
     * Only use for unmapped databases, as sw dumps should be placed in sw folder.
     *
     * @param array $archivePaths
     */
    private function _unzipArchivesUnmappedDb(array $archivePaths)
    {
        foreach ($archivePaths as $archive) {
            $destination = rtrim($archive, '.gz');
            $this->_gunzip($archive, $destination);
        }
    }

    /**
     * restore unmapped db to local db.
     *
     * @param string $dbName
     * @param array  $sqlFiles
     */
    private function _restoreUnmappedDatabase($dbName, array $sqlFiles)
    {
        $Importer = new Model_RecoveryPoint_Databases_UnmappedDbImporter($dbName, $sqlFiles);
        $Importer->recoverDatabase();
    }

    /**
     * @param string $user
     * @param array  $dbs
     */
    public function restoreDatabasesAltLocation($user, array $dbs)
    {
        // YYYY-MM-DD-MM-SS
        $newDirName = date("Y-m-d-H-i-s");
        $destination = self::NW_DOWNLOAD_DIR_PATH . "/$newDirName/$user";
        $this->_restoreUserDbsToAltLocation($user, $dbs, $destination);
    }
}
