<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 28, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_RecoveryPoint_Files_Nodeworx extends Model_RecoveryPoint_Files
{
    /**
     * Get root content (chroot).
     *
     * @return array
     */
    public function getRootContent()
    {
        return $this->_getRootContent();
    }

    /**
     * Get directory content by path.
     *
     * @param string $path
     * @return array
     */
    public function getDirectoryContent($path)
    {
        $path = ltrim($path, '/');
        $dir = $this->_getDirByPath($path);
        return $dir[self::DIR_CONTENT];
    }

    /**
     * @param array   $paths
     * @param boolean $deleteNewerFiles
     */
    public function recoverDirectories(array $paths, $deleteNewerFiles = false)
    {
        $ids = $this->_getDirIdsByPaths($paths);
        $this->_recoverDirectories($ids, $deleteNewerFiles);
    }

    /**
     * @param array $paths
     */
    public function restoreToAltLocation(array $paths)
    {
        $ids = $this->_getDirIdsByPaths($paths);
        $this->_restoreToAltLocation($ids);
    }

    /**
     * @param array $dirIds
     */
    private function _restoreToAltLocation(array $dirIds)
    {
        // YYYY-MM-DD-MM-SS
        $newDirName = date("Y-m-d-H-i-s");

        // TODO validate path if set
        $path = self::NW_DOWNLOAD_DIR_PATH . "/$newDirName/";

        $this->_createRestoreAltLocationDir($path);
        $this->_getApi()->recoverDirectoriesToAltLocation($this->getAgentTenantId(), $dirIds, $path);
    }


    /**
     * Get alt location path.
     *
     * @return string
     */
    public static function getRestoreAltLocationPath()
    {
        return self::NW_DOWNLOAD_DIR_PATH;
    }
}
