<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Aug 17, 2020
 */

/**
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_RecoveryPoint_Files_Siteworx extends Model_RecoveryPoint_Files
{
    /**
     * Get root content for sw user.
     *
     * @return array
     */
    public function getRootContent()
    {
        $homeContent = $this->_getHomeContent();
        $rootName = $this->_getSwRootName();
        $rootId = $this->_getDirIdByName($homeContent, $rootName);
        $rootContent = $this->_getDirectoryContentById($rootId);
        $filtered = $this->_filterSwRootContent($rootContent);

        return $filtered;
    }

    /**
     * Get sw root dir name.
     *
     * @return string
     */
    private function _getSwRootName()
    {
        $rootPath = IW::SW()->getPackageRoot();
        $baseDirName = end(explode('/', $rootPath));
        return $baseDirName;
    }

    /**
     * filter sw root content should exclude var.
     *
     * @param array $content
     * @return array
     */
    private function _filterSwRootContent(array $content)
    {
        $filtered = array_filter($content, function ($dir) {
            return $dir['name'] !== 'var';
        });

        return array_values($filtered);
    }

    /**
     * Get sw alt location path.
     *
     * @param Siteworx $SW
     * @return string
     */
    public static function getRestoreAltLocationPath(Siteworx $SW)
    {
        $root = $SW->getPackageRoot();
        $recoveryDir = self::RECOVERY_DIR_NAME;
        return "$root/$recoveryDir";
    }

    /**
     * @param string $path
     * @return array
     */
    public function getDirectoryContent($path)
    {
        $this->_validatePath($path);
        $dir = $this->_getDirByPath($path);
        return $dir[self::DIR_CONTENT];
    }

    /**
     * Ensures path is within sw user folder.
     *
     * @param string $path
     */
    private function _validatePath($path)
    {
        if (!$this->_dirPathValid($path)) {
            throw new Exception_InvalidPath($path);
        }
    }

    /**
     * Make sure dir is inside sw folder.
     *
     * @param string $dirPath
     */
    protected function _dirPathValid($dirPath)
    {
        $packageRoot = IW::SW()->getPackageRoot();
        $pathIsValid = strpos($dirPath, $packageRoot) !== false;
        return $pathIsValid;
    }

    /**
     * @param array   $paths
     * @param boolean $deleteNewerFiles
     */
    public function recoverDirectories(array $paths, $deleteNewerFiles = false)
    {
        $this->_validatePaths($paths);

        $ids = $this->_getDirIdsByPaths($paths);
        $this->_recoverDirectories($ids, $deleteNewerFiles);
    }

    /**
     * @param array $paths
     */
    private function _validatePaths(array $paths)
    {
        foreach ($paths as $path) {
            $this->_validatePath($path);
        }
    }

    /**
     * @param array $paths
     */
    public function restoreToAltLocation(array $paths)
    {
        $this->_validatePaths($paths);
        $ids = $this->_getDirIdsByPaths($paths);
        $this->_restoreToAltLocation($ids);
    }

    /**
     * @param array $dirIds
     */
    private function _restoreToAltLocation(array $dirIds)
    {
        $newDirName = date("Y-m-d-H-i-s");
        $path = self::getRestoreAltLocationPath(IW::SW()) . "/$newDirName/";

        $this->_createRestoreAltLocationDir($path);
        $this->_getApi()->recoverDirectoriesToAltLocation($this->getAgentTenantId(), $dirIds, $path);
    }
}
