<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jun 05, 2020
 */

/**
 * Test class for Cron.
 *
 * @package Interworx
 * @subpackage
 */
class Cron_AcronisTest extends IWorx_Framework_TestCase
{
    const NEW_FOLDER_PATH = Model_RecoveryPoint_Files::NW_DOWNLOAD_DIR_PATH . "/testfolder";

    /**
     * Set up.
     */
    public function setUp()
    {
        $this->_addExpiredFolder();
    }

    /**
     * Add folder & update mod time so that cron detects that it expired.
     */
    private function _addExpiredFolder()
    {
        $this->_addFolder();
        $this->_updateModificationDate();
    }

    /**
     * Add test folder.
     */
    private function _addFolder()
    {
        $addFolder = 'mkdir -p ' . self::NEW_FOLDER_PATH;
        $Command = new Command($addFolder);
        $Command->runAsRoot();
        $Command->exec();
    }

    /**
     * Upfate mod time of test folder.
     */
    private function _updateModificationDate()
    {
        $updateModTime = 'touch -d "8 days ago" ' . self::NEW_FOLDER_PATH;
        $Command = new Command($updateModTime);
        $Command->runAsRoot();
        $Command->allowQuoteDouble();
        $Command->exec();
    }

    /**
     * Test cron task - should delete any folders older than 7 days.
     */
    public function testCronShouldDeleteExpiredBackups()
    {
        $this->assertFileExists(self::NEW_FOLDER_PATH);

        $Cron = new Cron_Acronis('run-one');
        $this->invokeMethod($Cron, '_execute');
        $this->assertFileNotExists(self::NEW_FOLDER_PATH);
    }

    /**
     * Remove test folder added in setup if test fails.
     */
    public function tearDown()
    {
        $Command = new Command('rm -rf ' . self::NEW_FOLDER_PATH);
        $Command->runAsRoot();
        $Command->exec();
    }
}
