<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 24, 2020
 */

require_once(__DIR__ . '/Mock.php');

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Mock_Server extends Mock
{
    /**
     * Get instanceId from cache or
     */
    public function getInstanceId()
    {
        $this->_throwExceptionIfSet();
        return 'instanceId';
    }

    /**
     * Get resource if from cache or api.
     *
     * @return string
     */
    public function getResourceId()
    {
        $this->_throwExceptionIfSet();
        return 'resourceid';
    }

    /**
     * Get device storage size.
     *
     * @return string
     */
    public function getStorageData()
    {
        $this->_throwExceptionIfSet();
        return array('size' => '1 GB');
    }

    /**
     * Is protected.
     *
     * @return boolean
     */
    public function isProtected()
    {
        // TODO return value & add set method.
        $this->_throwExceptionIfSet();
        return true;
    }

    /**
     * @return string
     * @throws Exception // if no applicable plan exists.
     */
    public function getPlanId()
    {
        $this->_throwExceptionIfSet();
        return 'id';
    }


    /**
     *
     * @return array
     */
    public function getBackupStatus()
    {
        $this->_throwExceptionIfSet();
        return array(
            'lastStatus' => 'running', // ctrl runBackup will await this, test will take longer if excluded.
            'nextBackup' => array('nextbackup'), // ctrl activateBackup will await this, test will take longer if excluded.
            'lastBackup' => array('lastBackup')
        );
    }

    /**
     * Get backups.
     *
     * @return array
     */
    public function getBackups()
    {
        $this->_throwExceptionIfSet();
        return array();
    }


    /**
     *
     * @return boolean
     */
    public function backupInProgress()
    {
        $this->_throwExceptionIfSet();
        return true;
    }

    /**
     *
     *
     * @return boolean
     */
    public function backupNotScheduled()
    {
        $this->_throwExceptionIfSet();
        return false;
    }
}
