<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 27, 2020
 */

require_once(__DIR__ . '/../../Model/Cache.php');

class AcronisTest extends IWorx_Framework_TestCase
{
    const ACTION_GET_API = '_getApi';
    const ACTION_GET_CACHE = '_getCache';
    const ACTION_GET_PLUGIN = '_getPlugin';

    private $_CacheMock;

    /**
     * get system under test.
     *
     * @param mixed $SutClass
     * @param mixed $ApiMock
     * @param mixed $args
     */
    protected function _getSutPartialMock($SutClass, $ApiMock = null, $args = null)
    {
        $SUT = $args === null ? $this->_getSutNoArgs($SutClass) : $this->_getSutWithConstructArgs($SutClass, $args);
        $this->_CacheMock = $this->_createCacheMock();

        $SUT->expects($this->any())
        ->method(self::ACTION_GET_CACHE)
        ->willReturn($this->_CacheMock);

        if (isset($ApiMock)) {
            $SUT->expects($this->any())
            ->method(self::ACTION_GET_API)
            ->willReturn($ApiMock);
        }

        return $SUT;
    }

    /**
     * Set SUT with constructor args.
     *
     * @param mixed $SutClass
     * @param mixed $args
     */
    private function _getSutWithConstructArgs($SutClass, $args)
    {
        $args = is_array($args) ? $args : array($args);

        $SUT = $this->getMockBuilder($SutClass)
        ->setMethods(['__construct', self::ACTION_GET_API, self::ACTION_GET_CACHE])
        ->setConstructorArgs($args)
        ->getMock();

        return $SUT;
    }

    /**
     * Get sut no args.
     *
     * @param mixed $SutClass
     */
    private function _getSutNoArgs($SutClass)
    {
        $SUT = $this->getMockBuilder($SutClass)
        ->setMethods([self::ACTION_GET_API, self::ACTION_GET_CACHE])
        ->getMock();

        return $SUT;
    }

    /**
     * get cache mock.
     */
    protected function _createCacheMock()
    {
        $Mock = $this->createMock(Model_Cache::class);
        return $Mock;
    }

    /**
     * Get cache mock.
     */
    protected function _getCacheMock()
    {
        return $this->_CacheMock;
    }
}
