<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 27, 2020
 */

require_once(__DIR__ . '/../../Model/Auth/Auth.php');
require_once(__DIR__ . '/Acronis.php');

/**
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Auth_AuthTest extends AcronisTest
{
    const LOGIN_LINK = 'someloginlink.com';

    private $_ApiMock;
    private $_SUT;

    /**
     * Set up before each test.
     */
    public function setUp()
    {
        $this->_ApiMock = $this->createMock(Model_Auth_Api::class);
        $this->_SUT = $this->_getSutPartialMock(Model_Auth_Auth::class, $this->_ApiMock);
    }

    /**
     * Test getOneTimeLoginLink. Should return link retrieved from api.
     */
    public function testGetOneTimeLoginLink()
    {
        $expected = self::LOGIN_LINK;
        $this->_configureMockApiReturnBackupLink($expected);

        $actual = $this->_SUT->getOneTimeLoginLink();
        $this->assertSame($expected, $actual);
    }

    /**
     * configure Api return value.
     *
     * @param string $loginLink
     */
    private function _configureMockApiReturnBackupLink($loginLink)
    {
        $this->_ApiMock->expects($this->any())
        ->method('getOneTimeLoginLink')
        ->willReturn($loginLink);
    }

    /**
     * test authorizeUser calls api
     */
    public function testAuthorizeUserCallsApi()
    {
        $this->_expectMockApiCalls('authorizeUser', 1);
        $this->_SUT->authorizeUser();
    }

    /**
     *
     *
     * @param string  $function
     * @param integer $calls
     */
    private function _expectMockApiCalls($function, $calls)
    {
        $amount = $calls > 1 ? $this->exactly($calls) : $this->any();

        $this->_ApiMock->expects($amount)
        ->method($function);
    }
}
