<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 27, 2020
 */

require_once(__DIR__ . '/Acronis.php');
require_once(__DIR__ . '/../../Model/BackupAgent/BackupAgent.php');
require_once(__DIR__ . '/../../CLI/AcronisInstaller.php');

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class BackupAgentTest extends AcronisTest
{

    const PREPOST_ADDED = 'prepostadded';

    /**
     * Test install() - should throw exception if backup agent installed already.
     */
    public function testInstallShouldThrowExceptionIfInstalled()
    {
        $backupAgentInstalled = true;
        $scriptsMissing = false;
        $SUT = $this->_getSut($backupAgentInstalled, $scriptsMissing);

        $this->expectException(Exception::class);
        $SUT->install();
    }

    /**
     * Test uninstall() - should throw exception if backup agent not installed.
     */
    public function testUninstallShouldThrowExceptionIfUninstalled()
    {
        $backupAgentInstalled = false;
        $scriptsMissing = true;
        $SUT = $this->_getSut($backupAgentInstalled, $scriptsMissing);

        $this->expectException(Exception::class);
        $SUT->uninstall();
    }

    /**
     * Should do nothing if scripts already in place.
     */
    public function testAddPrePostScriptsShouldDoNothing()
    {
        $backupAgentInstalled = true;
        $scriptsMissing = false;
        $SUT = $this->_getSut($backupAgentInstalled, $scriptsMissing);

        $SUT->expects($this->never())
            ->method('addPrePostScripts');

        $SUT->addPrePostScriptsIfMissing();
    }

    /**
     * Should call addPrePostScripts if scripts if missing.
     */
    public function testAddPrePostScriptsShouldAddScripts()
    {
        $backupAgentInstalled = true;
        $scriptsMissing = true;
        $SUT = $this->_getSut($backupAgentInstalled, $scriptsMissing);

        $SUT->expects($this->once())
            ->method('addPrePostScripts');

        $SUT->addPrePostScriptsIfMissing();
    }


    /**
     *
     * @param boolean $backupAgentInstalled
     * @param boolean $scriptsMissing
     */
    private function _getSut($backupAgentInstalled = true, $scriptsMissing = true)
    {

        $isInstalledFunction = 'isInstalled';
        $scriptsMissingFunction = 'scriptsMissing';
        $addPrePostFunction = 'addPrePostScripts';

        $SUT = $this->getMockBuilder(Model_BackupAgent_BackupAgent::class)
            ->setMethods([$isInstalledFunction, $scriptsMissingFunction, $addPrePostFunction])
            ->getMock();

        $SUT->expects($this->any())
            ->method($isInstalledFunction)
            ->willReturn($backupAgentInstalled);

        $SUT->expects($this->any())
            ->method($scriptsMissingFunction)
            ->willReturn($scriptsMissing);


        return $SUT;
    }
}
