<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 28, 2020
 */

require_once(__DIR__ . '/Acronis.php');
require_once(__DIR__ . '/../../Model/Backups/PlanDraft.php');
require_once(__DIR__ . '/../../Model/Backups/Api.php');

/**
 * Test PlanDraft class.
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class PlanDraftTest extends AcronisTest
{
    const NEW_PLAN_ID = 'newplanid';
    const NEW_DRAFT_ID = 'newdraftid';

    private $_SUT;

    /**
     * Set up.
     */
    public function setUp()
    {
        $this->_SUT = $this->_getSutPartialMock();
    }

    /**
     * getPlanId should throw exception if no plan has been created.
     */
    public function testGetPlanIdShouldThrowExceptionBeforePlanCreated()
    {
        $this->expectException(Exception::class);
        $this->_SUT->getPlanId();
    }

    /**
     * getPlanId should return new plan id if plan was created.
     */
    public function testGetPlanIdShouldReturnNewPlanIdIfPlanExists()
    {
        $this->_SUT->createPlan();

        $expected = self::NEW_PLAN_ID;
        $actual = $this->_SUT->getPlanId();

        $this->assertSame($expected, $actual);
    }


    /**
     * Get api mock
     */
    private function _getApiMock()
    {
        $Mock = $this->createMock(Model_Backups_Api::class);

        $Mock->expects($this->any())
        ->method('createPlan')
        ->willReturn(array('PlanID' => self::NEW_PLAN_ID));

        $Mock->expects($this->any())
        ->method('createDraft')
        ->willReturn(array('DraftID' => self::NEW_DRAFT_ID));

        return $Mock;
    }

    /**
     * Get sut partial mock. Mocked construct as methods are null otherwise, e.g. not returning mock api but null.
     */
    protected function _getSutPartialMock()
    {
        $SUT = $this->getMockBuilder(Model_Backups_PlanDraft::class)
            ->setMethods([self::ACTION_GET_API, self::ACTION_GET_CACHE])
            ->disableOriginalConstructor()
            ->getMock();

        $SUT->expects($this->any())
            ->method(self::ACTION_GET_CACHE)
            ->willReturn($this->_createCacheMock());

        $SUT->expects($this->any())
            ->method(self::ACTION_GET_API)
            ->willReturn($this->_getApiMock());


        return $SUT;
    }
}
