
import {
    createSpinner,
    toggleVisibility
} from '../helpers.js';

export const checkboxClass = 'ab-recovery-checkbox';

const $warningMessageContainer = $('#ab-restore-warning-message');
const $successMessageDiv = $('#ab-restore-success-message');
const $successMessageContainer = $successMessageDiv.parent();

export const $table = $('#ab-backups-table');
export const $tableHeader = $('#ab-table-header');
export const checkboxHtml = `<input type="checkbox" class="${checkboxClass}">`;

export const createTableRow = (id, className, $content, displayPath) => (
    `<tr class="${className}" id="${id}" data-path="${displayPath}">
        ${displayContent($content)}
    </tr>
    `);


const displayContent = content => Array.isArray(content) ? getTableItems(content) : getTableItem(content);
const getTableItems = items => items.map(item => getTableItem(item));
const getTableItem = item => `<td>${item}</td>`;

export const createHeaderRow = content => content.map(headerContent => `<th>${headerContent}</th>`);

export const displaySpinner = () => {
    let spinner = createSpinner();
    $table.html(`<div>${spinner} ${loadingBackupMessage}</div>`);
}

export const emptyTable = () => $table.html('');

const loadingBackupMessage = 'Loading the content. This may take a while.';

export const formatDate = date => `${date.day} ${date.month} ${date.year} ${date.time}`;

export const getLinkDisplayName = ($tableElement) => {
    let $link = $tableElement.find('a');
    return $link.text().trim();
}

export const getTableElementId = ($element) => {
    while (!$element.is('tr')) {
        $element = $element.parent();
    }

    return $element.attr('id');
}

export const replaceTableContent = (headerContent, tableContent) => {
    $tableHeader.html(headerContent);
    $table.html(tableContent);
}

export const getSelected = () => $table.find('input[type=checkbox]:checked');

export const getAllCheckboxes = () => $('input[type=checkbox]');

export const hideInProgress = () => {
    if ($warningMessageContainer.is(':visible')) {
        toggleVisibility($warningMessageContainer);
    }
}

export const showInProgress = (message) => {
    if ($warningMessageContainer.is(':hidden')) {
        $warningMessageContainer.html(message);
        toggleVisibility($warningMessageContainer);
    }
}

export const showSuccess = (message) => {
    if ($successMessageContainer.is(':hidden')) {
        closeSuccessMessageOnClick();
        $successMessageDiv.html(message);
        toggleVisibility($successMessageContainer);
    } else {
        $successMessageDiv.html(message);
    }
}

const closeSuccessMessageOnClick = () => {
    let $closeButton = $('#ab-close-success');

    // make sure multiple event handlers aren't registered
    $closeButton.unbind('click');
    $closeButton.on('click', () => toggleVisibility($successMessageContainer))

}

export const getSelectedIds = () => {
    let $selected = getSelected();
    let $ids = $selected.map((index, $checkbox) => $($checkbox.closest('tr')).attr('id'));
    return $ids.get();
}

export const getSelectedPaths = () => {
    let $selected = getSelected();
    let $paths = $selected.map((index, $checkbox) => $($checkbox.closest('tr')).attr('data-path'));
    return $paths.get();
}


export const getSelectedDatabaseNames = () => {
    let $selected = getSelected();
    let result = [];

    $selected.each((index, $checkbox) => {
        let $parent = $($checkbox.closest('tr'));
        let dbName = $parent.attr('id');
        result.push(dbName);
    });

    return result;
}

export const getSelectedDatabasesByUser = (user) => {
    let $selected = getSelected();

    let databases = $selected.map(($index, $checkbox) => {
        let $parent = $($checkbox.closest('tr'));
        let unixUser = $parent.children().last().text().trim();
        let database = $parent.attr('id');
        if (unixUser === user) {
            return database;
        }
    });

    return databases.get();
}

export const getSelectedUsers = () => {
    let $selected = getSelected();
    let unixUsers = [];

    $selected.each((index, $checkbox) => {
        let $parent = $checkbox.closest('tr');
        let unixUser = $($parent).children().last().text().trim();

        if (!unixUsers.includes(unixUser)) {
            unixUsers.push(unixUser);
        }
    });

    return unixUsers;
}

export const dirsSelected = () => getSelected().length > 0;

export const getTextSelectedDirNames = () => {
    let $selected = getSelected();
    let names = '';

    $selected.each((index, $dir) => {
        let $checkbox = $($dir);
        let $tableElement = $checkbox.parent().parent();

        let $nameElement = $tableElement.find('span').parent();
        let name = $nameElement.text().trim();
        names.length > 0 ? names += `, ${name}` : names = name;
    });

    return names;
}

export const closeModal = () => iw_lib.iw_modal_popup.hide();

export const addSelectAllListener = () => {
    let $tableHeaderCheck = $tableHeader.find(`.${checkboxClass}`);
    $tableHeaderCheck.unbind('click');
    $tableHeaderCheck.on('click', toggleSelectAll);
}

const toggleSelectAll = (event) => {
    let checkAllOrNone = $(event.target).prop('checked');
    $(`.${checkboxClass}`).prop('checked', checkAllOrNone);
}

export const openModal = (header, $content, width) => iw_lib.popupModal($content, header, null, null, null, width);