import { displaySpinner, getLinkDisplayName} from './backupsHelpers.js';
import { addToBreadcrumbs, createBreadcrumbs, breadcrumbsDirClass } from './breadcrumbs.js';
import { recoveryOptionClass, openRecoveryModal, openAltLocationModal } from './recoveryPoint.js';
import { loadDirClass } from './listDirContent.js';
import { backupItemClass } from './listBackups.js';
import { getBreadcrumbs } from '../sessionStorage/sessionStorage.js';
import { router } from './router.js';
import { startRecFilesAltLocationButtonId, startRecDbsAltLocationButtonId } from './altLocationModal.js';
import { recoverDbsButtonId, recoverFilesButtonId } from './recoveryModal.js';
import { restoreFiles, restoreFilesAltLocation, restoreDatabases, restoreDatabasesAltLocation } from '../ctrlActions.js';

const openRecoveryModalButtonId = 'ab-open-recovery-modal';
const openRecoveryAltLocationButtonId = 'ab-open-recovery-alt-location-modal';



export const activateEventHandlers = (controller) => {
    openAltLocationModalOnClick();
    openRecoveryModalOnClick();

    registerBackupsEventHandler();
    registerBackupOptionEventHandler();
    registerDirEventHandler();
    registerBreadcrumbsEventHandler();

    registerRecoverFilesAltLocationEventListener(controller);
    registerRecoverFilesEventListener(controller);
    registerRecoverDatabaseEventListener(controller);
    registerRecoverDatabasesAltLocationEventListener(controller);
}

const registerBackupsEventHandler = () => {
    $(document).off('click', `.${backupItemClass}`);
    $(document).on('click', `.${backupItemClass}`, (event) => {
        let $targetElement = $(event.currentTarget);
        let displayName = getLinkDisplayName($targetElement)
        let backupId = $targetElement.attr('id');

        displaySpinner();
        createBreadcrumbs(backupId, displayName);
    });
}

const registerBackupOptionEventHandler = () => {
    $(document).off('click', `.${recoveryOptionClass}`);
    $(document).on('click', `.${recoveryOptionClass}`, (event) => {
        displaySpinner();

        let $targetElement = $(event.currentTarget);
        let displayName = getLinkDisplayName($targetElement).toLowerCase();
        addToBreadcrumbs(displayName);
    });
}

const registerDirEventHandler = () => {
    $(document).off('click', `.${loadDirClass}`);
    $(document).on('click', `.${loadDirClass}`, (event) => {
        let $targetElement = $(event.currentTarget);
        let $parent = $targetElement.closest('tr');

        let path = $parent.attr('data-path');
        let name = getLinkDisplayName($targetElement);

        addToBreadcrumbs(name, path);
    });
}


const registerBreadcrumbsEventHandler = () => {
    $(document).off('click', `.${breadcrumbsDirClass}`);
    $(document).on('click', `.${breadcrumbsDirClass}`, (event) => {
        let $targetElement = $(event.currentTarget);
        let $breadcrumbsElements = $targetElement.parent().children();
        let currentIndex = $breadcrumbsElements.index($targetElement);

        let path = getBreadcrumbs().split('/').slice(0, currentIndex).join('/');
        router.route(path);
    });
}

const openRecoveryModalOnClick  = () => {
    let $buttonId = `#${openRecoveryModalButtonId}`;
    $(document).off('click', $buttonId);
    $(document).on('click', $buttonId, openRecoveryModal);
}

const openAltLocationModalOnClick = () => {
    let $buttonId = `#${openRecoveryAltLocationButtonId}`;
    $(document).off('click', $buttonId);
    $(document).on('click', $buttonId, openAltLocationModal);
}


const registerRecoverFilesEventListener = (controller) => {
    let btnSelector = `#${recoverFilesButtonId}`;
    $(document).off('click', btnSelector);
    $(document).on('click', btnSelector, () => restoreFiles(controller));
}

const registerRecoverFilesAltLocationEventListener = (controller) => {
    let recoveryButton = `#${startRecFilesAltLocationButtonId}`;
    $(document).off('click', recoveryButton);
    $(document).on('click', recoveryButton, () => restoreFilesAltLocation(controller));
}


const registerRecoverDatabaseEventListener = (controller) => {
    let btnSelector = `#${recoverDbsButtonId}`;
    $(document).off('click', btnSelector);
    $(document).on('click', btnSelector, () => restoreDatabases(controller));
}


const registerRecoverDatabasesAltLocationEventListener  = (controller) => {
    let btnSelector = `#${startRecDbsAltLocationButtonId}`;
    $(document).off('click', btnSelector);
    $(document).on('click', btnSelector, () => restoreDatabasesAltLocation(controller));
}
