import {
    toggleVisibility,
    handleResponseError
} from '../helpers.js';

import {
    emptyTable,
    replaceTableContent,
    createTableRow,
    formatDate
} from './backupsHelpers.js';

const tableEmptyId = 'ab-no-backups';
export const backupItemClass = 'ab-backup-item';

export const listBackupsCallback = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        listBackups(reply);
    }
}

const listBackups = (reply) => {
    let backups = reply.getReplyData();

    if (backups.length === 0) {
        emptyTable();
        toggleVisibility(tableEmptyId);
    } else {
        let tableRows = getTableRows(backups);
        let tableHeader = `<th>Date & time</th>`;
        replaceTableContent(tableHeader, tableRows);
    }
}

const getTableRows = (backups) => backups.map(backup => {
    let rowContent = getDateLink(backup.date);
    let tableRow = createTableRow(backup.backupId, backupItemClass, rowContent);
    return tableRow;
});

const getDateLink = (date) => `<span class="ab-icon icon-backup"></span><a>${formatDate(date)}</a>`;
