import { handleResponseError } from '../helpers.js';
import {
    createTableRow,
    createHeaderRow,
    replaceTableContent,
    checkboxHtml,
    addSelectAllListener
} from './backupsHelpers.js';
import { displayRecoveryButtons } from './recoveryButtons.js';

const databaseClass = 'ab_db';

export const displayDatabases = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        displayRecoveryButtons();

        let unixUsers = reply.getReplyData();
        if (dbsEmpty(unixUsers)) {
            displayNoDatabases();
        } else {
            listDatabasesByUser(unixUsers);
        }
    }
}

const displayNoDatabases = () => {
    let content = '<div class="ab-no-table-content"> No database backups available </div>';
    let header = getHeader();
    replaceTableContent(header, content);
}

const listDatabasesByUser = (unixUsers) => {
    let newTableHeader = getHeader();
    let newTableContent = getUnixUsersTableContent(unixUsers);

    replaceTableContent(newTableHeader, newTableContent);
    addSelectAllListener();
}

const getHeader = () => createHeaderRow([checkboxHtml, 'Name', 'Owner']);

const dbsEmpty = (users) => {
    let isEmpty = true;

    users.forEach(user => {
        if (user.dbNames.length > 0) {
            isEmpty = false;
        }
    });

    return isEmpty;
}

const getUnixUsersTableContent = (users) => {
    let rows = [];
    users.forEach(user => {
        rows = rows.concat(getUserRows(user));
    });

    return rows;
};

const getUserRows = (user) => {
    let rows = [];
    let dbs = user.dbNames;
    let owner = user.unixUser;

    dbs.forEach(dbName => {
        let dbClass = owner === 'system' ? 'ab-icon-system-database' : 'ab-icon-database';
        let db = `<span class="ab-icon ${dbClass}"></span> ${dbName}`;
        let displayContent = [checkboxHtml, db, owner];
        let row = createTableRow(dbName, databaseClass, displayContent);
        rows.push(row);
    });

    return rows;
}

export const displaySwDatabases = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        displayRecoveryButtons();

        let dbs = reply.getReplyData();

        if (dbs.length === 0) {
            displayNoDatabases();
        } else {
            listSwDatabases(dbs);
        }
    }
}

const listSwDatabases = (dbs) => {
    let newTableHeader = createHeaderRow([checkboxHtml, 'Name']);
    let newTableContent = getSwTableContent(dbs);

    replaceTableContent(newTableHeader, newTableContent);
    addSelectAllListener();
}

const getSwTableContent = (dbs) => {
    let rows = [];
    dbs.forEach(dbName => {
        let db = `<span class="ab-icon ab-icon-database"></span> ${dbName}`;
        let displayContent = [checkboxHtml, db];
        let row = createTableRow(dbName, databaseClass, displayContent);
        rows.push(row);
    });

    return rows;
};
