import { handleResponseError } from '../helpers.js';
import { displayRecoveryButtons } from './recoveryButtons.js';
import {
    createTableRow,
    createHeaderRow,
    replaceTableContent,
    formatDate,
    checkboxHtml,
    addSelectAllListener
} from './backupsHelpers.js';

export const loadDirClass = 'ab_load_directory';
const dirClass = 'ab_directory';
const fileClass = 'ab_file';


export const displayDirContent = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        handleSuccess(reply);
    }
}

const handleSuccess = (reply) => {
    let dirContent = reply.getReplyData();

    if (dirContent.length === 0) {
        displayNoFiles();
    } else {
        displayContent(dirContent);
    }
}

const displayNoFiles = () => {
    let newTableContent = '<div class="ab-no-table-content"> No files to display! </div>';
    let newTableHeader = createHeaderRow([checkboxHtml, 'Name', 'Modified']);

    replaceTableContent(newTableHeader, newTableContent);
}

const displayContent = (dirContent) => {
    displayRecoveryButtons();

    let newTableContent = getNewTableContent(dirContent);
    let newTableHeader = createHeaderRow([checkboxHtml, 'Name', 'Modified']);

    replaceTableContent(newTableHeader, newTableContent);
    addSelectAllListener();
}

const getNewTableContent = (content) => {
    // sorting content so that dirs are displayed before files
    let sortedContent = content.sort((a, b) => (a.type > b.type) ? 1 : ((b.type > a.type) ? -1 : 0));
    let rows = getRows(sortedContent);
    return rows;
};

const getRows = (content) => content.map(dir => {
    let className = isFile(dir) ? fileClass : dirClass;
    let displayContent = getDisplayContent(dir);

    return createTableRow(dir.id, className, displayContent, dir.displayPath);
});

const getDisplayContent = (dir) => {
    let nameElement = isFile(dir) ? getFileNameElement(dir.name) : getDirectoryNameElement(dir.name);
    let size = isFile(dir) ? dir.size : '';
    let modified = formatDate(dir.modified);

    return [checkboxHtml, nameElement, modified, size];
}

const getFileNameElement = (fileName) => (
    `
    <div>
        <span class="ab-icon ab-icon-file"></span>
        ${fileName}
    </div>
    `
);

const getDirectoryNameElement = (dirName) => (
    `
    <div class="${loadDirClass}">
        <span class="ab-icon ab-icon-folder"></span>
        <a>
            ${dirName}
        </a>
    </div>
    `
);

const isFile = (dir) => dir.type === 'file';
