import { createTableRow, replaceTableContent, hideInProgress, showSuccess } from './backupsHelpers.js';
import { getFilesLocationHtml, openFileAltLocationModal, openDatabaseAltLocationModal } from './altLocationModal.js';
import { openFileRecoveryModal, openDatabaseRecoveryModal } from './recoveryModal.js';
import { getRecoveryType } from './router.js';
import { handleResponseError } from '../helpers.js';
import { getRecoveryNames } from '../sessionStorage/sessionStorage.js';

export const recoveryOptionClass = 'recovery-option';

export const listRecoveryPointOptions = () => {
    let tableRows = getTableRows();
    let tableHeader = `<th>Types</th>`;
    replaceTableContent(tableHeader, tableRows);
}

const getTableRows = () => {
    let recoveryOptions = getRecoveryOptions();

    let tableRows = recoveryOptions.map(option => {
        let link = `<span class="ab-icon ${option.class}"></span><a>${option.display}</a>`;
        return createTableRow(option.id, recoveryOptionClass, link)
    });

    return tableRows;
}

export const getRecoveryOptions = () => ([
    {
        id: 'file-recovery',
        display: 'Files',
        class: 'ab-icon-file',
        openRecoveryModal: openFileRecoveryModal,
        openAltLocationModal: openFileAltLocationModal
    },
    {
        id: 'db-recovery',
        display: 'Databases',
        class: 'ab-icon-database',
        openRecoveryModal: openDatabaseRecoveryModal,
        openAltLocationModal: openDatabaseAltLocationModal
    },
    // {
    //     id: 'email-recovery',
    //     display: 'Email'
    // },
    // {
    //     id: 'forwarder-recovery',
    //     display: 'Email forwarders'
    // },
    // {
    //     id: 'account-recovery',
    //     display: 'Accounts'
    // }
]);

export const openRecoveryModal = () => {
    let options = getRecoveryOptions();
    options.forEach(option => {
        if (option.display.toLowerCase() === getRecoveryType()) {
            option.openRecoveryModal();
        }
    });
}

export const openAltLocationModal = () => {
    let options = getRecoveryOptions();
    options.forEach(option => {
        if (option.display.toLowerCase() === getRecoveryType()) {
            option.openAltLocationModal();
        }
    });
}



export const callbackRestoreAltLocation = (reply, success) => {
    hideInProgress();

    if (!success) {
        handleResponseError(reply);
    } else {
        showSuccess(`Successfully recovered files to ${getFilesLocationHtml()}. It may take up to 30 minuts for the content to apper on the server.`)
    }
}

export const callbackRecoverFiles = (reply, success) => {
    hideInProgress();

    if (!success) {
        handleResponseError(reply);
    } else {
        let successMessage = 'Successfully recovered files: ' + getRecoveryNames();
        showSuccess(successMessage);
    }
}

export const callbackRestoreDatabases = (reply, success) => {
    hideInProgress();

    if (!success) {
        handleResponseError(reply);
    } else {
        showSuccess('Successfully recovered databases');
    }
}

export const callbackRestoreDbsAltLocation = (reply, success) => {
    hideInProgress();

    if (!success) {
        handleResponseError(reply);
    } else {
        let msg = getRecoverDbsAltLocationSuccessMessage();
        showSuccess(msg)
    }
}

export const getRecoverDbsAltLocationSuccessMessage = () => {
    return `Successfully recovered sql files to ${getFilesLocationHtml()}.
    It may take up to 30 minuts for the content to apper on the server.`;
}