import {
    getSelectedPaths,
    closeModal,
    showInProgress,
    getTextSelectedDirNames,
    displaySpinner,
    dirsSelected
} from './backups/backupsHelpers.js';

import {
    getBackupId,
    setRecoveryNames,
    callbackSetAltLocation,
    getDirectoryPath
} from './sessionStorage/sessionStorage.js';

import {
    callbackRestoreAltLocation,
    callbackRecoverFiles
} from './backups/recoveryPoint.js';

import { deleteCheckboxSelected } from './backups/recoveryModal.js';
import { displayDirContent } from './backups/listDirContent.js';
import { listBackupsCallback } from './backups/listBackups.js';
import { displayDatabases, displaySwDatabases } from './backups/listDatabases.js';
import { alertsCallback } from './nw/dashboard/alerts.js';
import { loadSectionsCallback } from './nw/dashboard/sections.js';
import { nwActions } from './nw/ctrlActions.js';
import { swActions } from './sw/ctrlActions.js';

export const nwController = '/nodeworx/acronis';
export const swController = '/siteworx/acronis';

const xhrTokenInput = {
    iw_payload_output: 'json',
    security_token: iw_js_data.iw_env.security_token
};

export const xhrTokenInputArgs = (path) => ({
    ab_backup_id: getBackupId(),
    ab_directory_path: path
});

const xhrInputWithSelectedDirs = () => {
    let paths = getSelectedPaths();
    let input = xhrTokenInputArgs();

    // TODO update this in form! to paths & lang file
    input['ab_directories_paths'] = paths;

    return input;
}

export const sendNwCtrlRequest = (actionToCall, callback, args) => {
    sendCtrlRequest(nwController, callback, actionToCall, args);
};

export const sendSwCtrlRequest = (actionToCall, callback, args) => {
    sendCtrlRequest(swController, callback, actionToCall, args);
};

const sendCtrlRequest = (ctrl, callback, action, args) => {
    iw_ctrl_handler.execute(null, callback, ctrl, action, { ...xhrTokenInput, ...args })
}

export const loadDirContent = (controller) => {
    displaySpinner();

    let action = 'getDirectoryContentCommit';
    let dirPath = getDirectoryPath();
    let args = xhrTokenInputArgs(dirPath);

    sendCtrlRequest(controller, displayDirContent, action, args);
}


export const loadRootContent = (controller) => {
    displaySpinner();

    let args = xhrTokenInputArgs();
    let action = 'getRootContentCommit';

    sendCtrlRequest(controller, displayDirContent, action, args);
}

export const restoreFiles = (controller) => {
    // get this value before modal is closed
    let deleteOldFiles = deleteCheckboxSelected();
    closeModal();

    if (dirsSelected()) {
        let filesToRecover = getTextSelectedDirNames();
        setRecoveryNames(filesToRecover);
        showInProgress('Recovery in progress...');

        let args = xhrInputWithSelectedDirs();
        args['ab_delete_files'] = deleteOldFiles;
        let action = 'recoverDirectoriesCommit';
        sendCtrlRequest(controller, callbackRecoverFiles, action, args);
    }
}

export const restoreFilesAltLocation = (controller) => {
    closeModal();

    if (dirsSelected()) {
        showInProgress('Downloading files to server...');

        let action = 'restoreToAltLocationCommit';
        let args = xhrInputWithSelectedDirs();
        sendCtrlRequest(controller, callbackRestoreAltLocation, action, args);
    }
}

export const listBackups = (controller) => {
    displaySpinner();
    setAltLocation(controller);

    let action = 'listBackupsCommit';
    sendCtrlRequest(controller, listBackupsCallback, action);
}

const setAltLocation = (controller) => {
    let action = 'getRestoreAltLocation';
    sendCtrlRequest(controller, callbackSetAltLocation, action);
}


export const getAltLocationXhr = (controller) => {
    let action = 'getRestoreAltLocation';
    sendCtrlRequest(controller, callbackSetAltLocation, action);
}

export const listDatabases = (controller) => {
    let action = 'listDatabasesCommit';
    let args = xhrTokenInputArgs();
    let cb = controller === swController ? displaySwDatabases : displayDatabases;

    displaySpinner();
    sendCtrlRequest(controller, cb, action, args);
}

export const restoreDatabases = (controller) => {
    closeModal();
    showInProgress('Recovering databases...');

    controller === swController ? swActions.restoreDatabases() : nwActions.restoreDatabases();
}

export const restoreDatabasesAltLocation = (controller) => {
    closeModal();
    showInProgress('Recovering databases to alt location...');

    controller === swController ? swActions.restoreDatabasesAltLocation() : nwActions.restoreDatabasesAltLocation();
}

export const displayAlerts = () => {
    let action = 'getAlertsCommit';
    let args = xhrTokenInput;
    sendNwCtrlRequest(action, alertsCallback, args);
}

export const loadDashboardSections = () => sendNwCtrlRequest('getDashboardDataCommit', loadSectionsCallback);
