const imgPath = '/plugins/assets/acronis/images/ajax-loader.gif';
const spinnerClass = 'ab-spinner';
const sessionStorageKeyMessages = 'messages';

export const refreshPage = () => location.reload();

export const createSpinner = () => {
    return (`
    <div class="${spinnerClass}">
        <img src="${imgPath}" alt="loading">
    </div>`
    );
}

export const loadMessages = () => {
    let message = getMessage();

    if (message && message.type === 'error') {
        displayErrorMessage(message.message);
    }

    if (message && message.type === 'success') {
         displaySuccessMessage(message.message)
    }

    if (message !== null) {
        // clear message once it has been displayed.
        sessionStorage.removeItem(sessionStorageKeyMessages);
    }
}

const getMessage = () => {
    let message = sessionStorage.getItem(sessionStorageKeyMessages);
    return JSON.parse(message);
}

export const setMessage = (type, message) => {
    let storageMessage = JSON.stringify({
        type: type,
        message: message
    });

    sessionStorage.setItem(sessionStorageKeyMessages, storageMessage);
}

export const displayErrorMessage = (message) => iw_lib.iw_message_banner(message, 'iw-negative');
export const displaySuccessMessage = (message) => iw_lib.iw_message_banner(message, 'iw-positive');

export const setMessageAndRefreshPage = (type, message) => {
    setMessage(type, message);
    refreshPage();
}





export const clearMessages = () => sessionStorage.removeItem(sessionStorageKeyMessages);

export const handleResponseError = (reply) => {
    let data = reply.getReplyData();
    displayErrorMessage(data.message);
}

export const toggleVisibility = (idOrElement) => {
    let isString = typeof idOrElement === 'string';

    let $element = isString ? $(`#${idOrElement}`) : idOrElement;
    $element.toggleClass('hide');
}


