import { getSelectedUsers, getSelectedDatabasesByUser, hideInProgress, showSuccess } from '../backups/backupsHelpers.js';
import { getBackupId } from '../sessionStorage/sessionStorage.js';
import { nwController } from '../ctrlActions.js';
import { displayErrorMessage } from '../helpers.js';
import { getRecoverDbsAltLocationSuccessMessage } from '../backups/recoveryPoint.js';


const restoreDatabasesAltLocation = () => {
    let promises = getRestoreDbsAltLocationPromises();
    Promise.all(promises)
        .then(() => {
            hideInProgress();
            let msg = getRecoverDbsAltLocationSuccessMessage();
            showSuccess(msg);
        })
        .catch((error) => {
            hideInProgress();

            let data = error.d;
            displayErrorMessage(data.message);
        })
}

let getRestoreDbsAltLocationPromises = () => {
    let action = 'restoreDatabasesAltLocationCommit';
    return getSelectedUsers().map(user => getRequestPromise(user, action));
}

const restoreDatabases = () => {
    let promises = getRestoreDbsPromises();
    Promise.all(promises)
        .then(() => {
            hideInProgress();
            showSuccess('Databases successfully recovered');
        })
        .catch((error) => {
            hideInProgress();

            let data = error.d;
            displayErrorMessage(data.message);
        })
}

let getRestoreDbsPromises = () => {
    let action = 'restoreDatabasesCommit';
    return getSelectedUsers().map(user => getRequestPromise(user, action));
}

let getRequestPromise = (unixUser, action) =>
    $.post('/xhr.php', getAjaxDataRestoreDatabases(unixUser, action))
        .then(response => new Promise((resolve, reject) => {
            let parsed = JSON.parse(response);
            let responseCode = parsed.c;
            responseCode === 201 ? resolve(parsed) : reject(parsed);
        }));




    const getAjaxDataRestoreDatabases = (unixUser, action) => {
        let databases = getSelectedDatabasesByUser(unixUser);
        return {
            i: JSON.stringify({
                r: 'Controller',
                i: {
                    iw_payload_output: 'json',
                    security_token: iw_js_data.iw_env.security_token,
                    ab_backup_id: getBackupId(),
                    c: nwController,
                    a: action,
                    iw_sess_hint: 'nodeworx',
                    where_was_i: '/nodeworx/acronis?tab=backups',
                    databases: databases,
                    unixuser: unixUser
                }
            })
        }
    };

    export const nwActions = {
        restoreDatabases: restoreDatabases,
        restoreDatabasesAltLocation: restoreDatabasesAltLocation
    }
