import { sendNwCtrlRequest } from '../../ctrlActions.js';

import {
    abCreateTitleCol,
    abCreateCol,
    abCreateRow,
    getBackupDateColNoDate,
    getBackupTimeCol,
    getBackupDateCol
} from './dashboardHelpers.js';

import { refreshPage } from '../../helpers.js';

export let loadLastBackupSection = (lastBackupDate, backupStatus) => {

    let $firstRow = getFirstRow(lastBackupDate);
    let $secondRow = getSecondRow(lastBackupDate, backupStatus);

    let $container = getContainer();
    $container.html([$firstRow, $secondRow]);

    if (backupStatus && backupInProgress(backupStatus)) {
        trackBackupProgress();
    }
}

let getContainer = () => {
    return $('#dashboard-lastbackup');
}

let getFirstRow = (date) => {
    let $titleCol = abCreateTitleCol('LAST BACKUP');
    let $backupDateCol = date ?
        getBackupDateCol(date) :
        getBackupDateColNoDate('Never');

    let rowContent = [$titleCol, $backupDateCol];
    let $firstRow = abCreateRow(rowContent);
    return $firstRow;
}

let getSecondRow = (backupDate, status) => {
    let $rowContent = getDateContent(backupDate, status);
    let $secondRow = abCreateRow($rowContent);

    $secondRow.addClass('vertical-spacer');
    return $secondRow;
}

let getDateContent = (backupDate, status) => {
    let $timeCol = backupDate ? getBackupTimeCol(backupDate.time) : getBackupTimeCol();
    let content = [$timeCol];

    if (backupDate) {
        let $statusCol = getStatusCol(status);
        content.unshift($statusCol);
    }

    return content;
}

let getStatusCol = (status) => {
    let statusInfo = getStatusInfo(status);

    let $iconSpan = $(`<span class="ab-icon-large ${statusInfo.class}" id="backup-status-icon"></span>`);
    let $textSpan = $(`<span class="icon-label" id="backup-status-label">${statusInfo.text}</span>`);

    let content = [$iconSpan, $textSpan];
    let $col = abCreateCol(content);
    $col.addClass('vertical-align');
    return $col;
}

let getStatusInfo = (status) => {
    let result = {
        text: 'Failed',
        class: 'icon-fail-large'
    }

    if (status === 'ok') {
        result.text = 'Succeeded';
        result.class = 'icon-success-large';
    }

    if (status === 'running') {
        result.text = 'Running';
        result.class = 'icon-in-progress-large';
    }

    return result;
}

let trackBackupProgress = () => {
    let action = 'getBackupActivitiesCommit';
    sendNwCtrlRequest(action, awaitBackupComplete);
}

let awaitBackupComplete = (reply, success) => {
    // TODO handle !success
    let backupData = reply.getReplyData();
    let status = backupData.lastStatus;

    if (backupInProgress(status)) {
        // check backup status in 15 seconds.
        setTimeout(trackBackupProgress, 15000);
    } else {
        refreshPage();
    }
}

let backupInProgress = (status) => status === 'running';