import { sendNwCtrlRequest } from '../../ctrlActions.js';

import {
    abCreateTitleCol,
    abCreateCol,
    abCreateRow,
    getBackupDateColNoDate,
    getBackupTimeCol,
    getBackupDateCol
} from './dashboardHelpers.js';


import {
    createSpinner,
    setMessageAndRefreshPage,
    handleResponseError
} from '../../helpers.js';

const runBackupContainerId = 'ab-run-backup';

export const loadNextBackupSection = (nextBackupDate, status) => {
    let $firstRow = getFirstRow(nextBackupDate);
    let $secondRow = nextBackupDate ? getSecondRow(nextBackupDate.time, status) : getSecondRowNoData();

    let $container = $('#dashboard-nextbackup');
    $container.html([$firstRow, $secondRow]);
}

let getFirstRow = (date) => {
    let $titleCol = abCreateTitleCol('NEXT BACKUP');
    let $backupDateCol = date ? getBackupDateCol(date) : getBackupDateColNoDate('Not scheduled');

    // add cols to row
    let rowContent = [$titleCol, $backupDateCol];
    let $firstRow = abCreateRow(rowContent);
    return $firstRow;
}

let getSecondRow = (time, status) => {
    let $backupLinkCol = getBackupLinkCol(status);
    let $backupTimeCol = getBackupTimeCol(time);
    let rowContent = [$backupLinkCol, $backupTimeCol];

    let $row = abCreateRow(rowContent);
    $row.addClass('vertical-spacer');

    return $row;
}

let getSecondRowNoData = () => {
    let $backupTimeCol = getBackupTimeCol();
    let rowContent = [$backupTimeCol];

    let $row = abCreateRow(rowContent);
    $row.addClass('vertical-spacer');

    return $row;
}

let getBackupLinkCol = (status) => {

    let runBackupId = 'ab-run-backup';
    let $img = '<img class="backup-icon" src="/plugins/assets/acronis/images/ico_run_now.svg" alt="backup now">';
    let $span = '<span>Run now</span>';
    let hide = status === 'running' ? 'class="hide"' : '';

    let $div = $(
        `<div id="${runBackupContainerId}" ${hide}>
        <a id="${runBackupId}">${$img}${$span}</a>
        </div>`
    );


    $(document).on('click', `#${runBackupId}`, runBackup);
    return abCreateCol($div);
}

let getRunBackupContainer = () => $(`#${runBackupContainerId}`);

let runBackup = () => {

    addSpinnerToBackupAction();
    let action = 'runBackupCommit';
    sendNwCtrlRequest(action, runBackupCallback);
}

let addSpinnerToBackupAction = () => {
    let $runBackupContainer = getRunBackupContainer();
    let $spinner = createSpinner();

    $runBackupContainer.html($spinner);
}

let runBackupCallback = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        let type = 'success';
        let message = 'The backup has started.';
        setMessageAndRefreshPage(type, message);
    }
}