import { getBreadcrumbPath } from '../backups/router.js';

const breadcrumbsKey = 'ab-breadcrumbs';
const recoveredFilesKey = 'ab-recovered';
const locationKey = 'ab-sw-alt-location';

export const setBreadcrumbs = (path) => sessionStorage.setItem(breadcrumbsKey, path);
export const getBreadcrumbs = () => sessionStorage.getItem(breadcrumbsKey);
export const deleteBreadcrumbs = () => sessionStorage.removeItem(breadcrumbsKey);

export const setRecoveryNames = (names) => sessionStorage.setItem(recoveredFilesKey, names);
export const getRecoveryNames = () => sessionStorage.getItem(recoveredFilesKey);


export const getAltLocation = () => sessionStorage.getItem(locationKey);
export const callbackSetAltLocation = (reply, success) => success && setAltLocation(reply.getReplyData().altLocation);
const setAltLocation = (location) => sessionStorage.setItem(locationKey, location);

export const setBackupId = (breadcrumbPath, backupId) => {
    let details = getStringifiedPathDetails(backupId);
    backupId && sessionStorage.setItem(breadcrumbPath, details);
};

export const setPath = (breadcrumbPath, dirPath) => {
    let backupId = getBackupId();
    let details = getStringifiedPathDetails(backupId, dirPath);

    sessionStorage.setItem(breadcrumbPath, details);
}

const getStringifiedPathDetails = (backupId, dirPath) => JSON.stringify({
    backupId: backupId,
    dirPath: dirPath
});


export const getDirectoryPath = () => {
    let breadcrumbPath = getBreadcrumbPath();
    let details = JSON.parse(sessionStorage.getItem(breadcrumbPath));
    return details.dirPath;
}

export const getBackupId = () => {
    let breadcrumbPath = getBreadcrumbPath();
    let details = JSON.parse(sessionStorage.getItem(breadcrumbPath));
    return details.backupId;
}