#!/bin/bash

trap onError ERR

DIR="$(dirname "${BASH_SOURCE[0]}")"
MYPW=$(grep dsn /usr/local/interworx/iworx.ini | grep -v interworx | sed -e 's/.*\/\/iworx://' -e 's/@unix(\/.*//')

mydef="$DIR"/ACRONIS.my.cnf
sed '/^password=/d' -i $mydef
echo "password='$MYPW'" >> $mydef

source "$DIR"/capture-data-config.sh

mysqldir=$TMP_BACKUP_DIR/pre-acronis-mysql
[ ! -d $mysqldir/ ] && mkdir -p $mysqldir/
[ ! -d $mysqldir/log/ ] && mkdir $mysqldir/log/
log="$mysqldir/log/dump.log"
ec() { #color printing removed, may add back if I figure out the bugs.
        shift
        echo -e "${*}" | logit
}
logit() { #print passed stdin, add a timestamp and also echo to the logfile
        while read line; do
                echo "$line"
                echo "$(date -u +"%F %H:%M:%S %Z") $line" >> $log
        done
}
#Do not dump dbs if there may not be space. Set for 50% of datadir usage currently.
percofmysqlusage=50
mysql_datadir=$(mysql --defaults-file=$mydef -BNe 'show variables like "datadir"' | awk '{print $2}')
mysqldirsize=$(du -s $mysql_datadir | awk '{print $1}')
mysqlestusage=$(echo $(( mysqldirsize*50/100 )))
tmpdiravail=$(df /home | awk '{print $4}' | sed '1 d')
if [[ $mysqlestusage -gt $tmpdiravail ]] ; then
        echo Estimated db dumps to large for available space. $mysqlestusage greater than $tmpdiravail
        echo Adjust percofmysqlusage= in plugins/acronis/scripts/AgentCommData/create-mysql-dumps.sh if needed.
        exit
fi

#We may need to think about how we are going to handle remote db servers.  For now I think we exclude and look at adding an option later to include.  A dedicated mysql server should really have its own backups.
#Set mysqldump options.
mysqldumpopts="--opt --routines --force --log-error=$remote_tempdir/dumps.log --max_allowed_packet=1000000000"

#Not really needed but might as well grab the grants.
mysql --defaults-file=$mydef -B -N -e "SELECT DISTINCT CONCAT('SHOW GRANTS FOR ''', user, '''@''', host, ''';') AS query FROM mysql.user" \
| while read i; do mysql --defaults-file=$mydef -e "$i"; done \
| sed 's/\(GRANT .*\)/\1;/;s/^\(Grants for .*\)/## \1 ##/;/##/{x;p;x;}' \
| sed 's/\\\\/\\/g' > $mysqldir/mysql.grants.local.sql

#user db tb dumps.
mysql_dumpsw() { #accepts user as $1, domain as $2
        [ ! -d $mysqldir/$user-dumps/ ] && mkdir $mysqldir/$user-dumps/
        local user=$1
        local dbs=$(siteworx -u --login_domain $domain -c MysqlDb -a listMysqlDatabases -n | awk '{print $2}')
        for db in $dbs; do
                [ ! -d $mysqldir/$user-dumps/$db ] && mkdir $mysqldir/$user-dumps/$db

                #schema only
                mysqldump --defaults-file=$mydef --no-data ${db} 2>> $mysqldir/log/dumps.log \
                | > $mysqldir/$user-dumps/${db}/${db}-schema-only.sql 2>> $mysqldir/log/dumps.log
                [ $? -eq 0 ] && echo ${db} >> $mysqldir/log/mapped.log

                # dump tables & routines/views
                local tables=$(mysql --defaults-file=$mydef ${db} -Bse 'show tables')
                [ "$tables" ] && for tb in $(echo $tables); do
                                mysqldump --defaults-file=$mydef $mysqldumpopts ${db} ${tb} 2>> $mysqldir/log/dumps.log \
                                | gzip -9 > $mysqldir/$user-dumps/${db}/${db}.${tb}.sql.gz 2>> $mysqldir/log/dumps.log
                done
        done
}

#Function for dumping unmapped dbs / not associated with a siteworx account.
mysql_dumpunmapped() { #accepts db as $1
        [ ! -d $mysqldir/system-dumps/ ] && mkdir $mysqldir/system-dumps/
        local dbs=$1
        for db in $dbs; do
                [ ! -d $mysqldir/system-dumps/$db ] && mkdir $mysqldir/system-dumps/$db

                mysqldump --defaults-file=$mydef --no-data ${db} 2>> $mysqldir/log/dumps.log \
                | > $mysqldir/system-dumps/${db}/${db}-schema-only.sql 2>> $mysqldir/log/dumps.log

                local tables=$(mysql --defaults-file=$mydef ${db} -Bse 'show tables')

                # dump tables
                [ "$tables" ] && for tb in $(echo $tables); do
                                mysqldump --defaults-file=$mydef $mysqldumpopts ${db} ${tb} 2>> $mysqldir/log/unmapped.log \
                                | gzip -9 > $mysqldir/system-dumps/${db}/${db}.${tb}.sql.gz 2>> $mysqldir/log/unmapped.log
                done
        done
}


#Get master domains and users for mysql dumps.
nodeworx -u -c Siteworx -a listMasterDomains | \
while read d ; do echo $d $(nodeworx -u -c Siteworx -a listAccounts -n | grep $'\t'$d | awk '{print $2}') ; done \
| while read domain user
do
mysql_dumpsw $user $domain >> $mysqldir/log/dblog.$user.log
done

#Dump missing dbs.
mysql --defaults-file=$mydef -e "show databases;"| sed '1 d' | grep -v 'performance_schema\|information_schema' | while read dbi ; do
        grep -q $dbi /chroot/home/.acronis_tmp/pre-acronis-mysql/log/mapped.log
        if [ $? -ne 0 ] ; then
		mysql_dumpunmapped $dbi >> $mysqldir/log/unmapped.log
	fi
done

sed '/^password=/d' -i $mydef
