#!/usr/bin/env bash

trap onError ERR

DIR="$(dirname "${BASH_SOURCE[0]}")"

source "$DIR"/capture-data-config.sh

onError() {
    echo -n "For more details please see \"$LOGFILE\""
}

log_msg() {
    local msg=$1
    echo "$(date -Ins) - ${msg}" >> "$LOGFILE"
}

log_msg "---------------------------------------------------------------------"

log_msg "Pre-capture data script started."

# Remove tmp backup dir if any.
[ -d $TMP_BACKUP_DIR/ ] && rm -rf $TMP_BACKUP_DIR/

# Remove acronis creds if any
[ -f $AB_ENV_CREDS ] && rm -rf $AB_ENV_CREDS


# TODO evaluate if needed
mount_points=$(findmnt -n -l -it "$MOUNTED_POINTS_EXCLUDED_FS" -o TARGET | egrep -v "$MOUNTED_POINTS_EXCLUDED_PATTERN")
while read -r mount_point; do
    /bin/rm -f "$mount_point/.mp"
done <<< "$mount_points"
while read -r mount_point; do
    if [ ! -d "$mount_point" ]; then
        continue
    fi
    mp_path="$mount_point/.mp"
    echo "$mount_point" >> "$mp_path"
    saving_mp_result=$?
    if [ "$saving_mp_result" -eq "0" ]; then
        log_msg "\"$mount_point\" has been added to \"$mp_path\""
    else
        log_msg "Cannot add \"$mount_point\" to \"$mp_path\", return code: $saving_mp_result"
    fi
done <<< "$mount_points"
log_msg "Placing files with mountpoints finished"

# Create folder structure backup.
log_msg "Saving folder structure to backups directory: $TMP_BACKUP_DIR"
mkdir --parents $TMP_BACKUP_DIR
saving_folder_structure=$(/home/interworx/bin/backup.pex --domains=all --structure-only --output-dir=$TMP_BACKUP_DIR)

    if [ "$saving_folder_structure" -eq "0" ]; then
        log_msg "folder structure successfully saved in temp directory $TMP_BACKUP_DIR"
    else
        log_msg "Cannot save domain structur to \"$TMP_BACKUP_DIR\", return code: $saving_folder_structure"
    fi

log_msg "Copying folder structure finished"

# TODO create mysql dumps
# TODO disk space check before running backup - skip db dumps if too low.
log_msg "Attempting to create mysql dumps if space allows..."
"$DIR"/create-mysql-dumps.sh
log_msg "Mysql dumps finished."

log_msg "Pre-capture data script finished."